import numpy as np
import pandas as pd


class Model:
    def __init__(self, models, do_ranking: bool):
        self.models = models
        self.do_ranking = do_ranking

    def predict(self, data):
        y_hat = np.zeros(data.shape[0])
        for model in self.models:
            pred = model.predict_proba(data)[:, 1]

            if self.do_ranking:
                pred = pd.Series(pred).rank()

            pred = pred / len(self.models)

            y_hat += pred
        return y_hat



import setuptools


setuptools.setup(
    name="easyensembling",                     # This is the name of the package
    version="0.0.3",                        # The initial release version
    author="dv",                     # Full name of the author
    packages=setuptools.find_packages(),    # List of all python modules to be installed                                     # Information to filter the project on PyPi website
    python_requires='>=3.6',                # Minimum version requirement of the package
    py_modules=["easyensembling"],             # Name of the python package
    package_dir={'': 'easyensembling/'},     # Directory of the source code of the package
    install_requires=[]                     # Install other dependencies if any
)